package main

import (
	"context"
	"flag"
	"log"
	"os"

	"git.netflux.io/rob/kubectl-persistent-logger/logs"
	"k8s.io/client-go/kubernetes"
	clientconfig "sigs.k8s.io/controller-runtime/pkg/client/config"
)

func main() {
	var (
		deployName  *string
		container   *string
		strictExist *bool
	)
	deployName = flag.String("deployment", "", "name of a deployment to monitor")
	container = flag.String("container", "", "name of a specific container")
	strictExist = flag.Bool("strict-exist", false, "require deployment to exist on launch")
	flag.Parse()

	cfg, err := clientconfig.GetConfig()
	if err != nil {
		log.Fatal(err)
	}

	clientset, err := kubernetes.NewForConfig(cfg)
	if err != nil {
		log.Fatal(err)
	}

	ctx := context.Background()
	watcher := logs.NewWatcher(
		*deployName,
		*container,
		*strictExist,
		logs.KubernetesClient{Interface: clientset},
		logs.NewPodWatcher,
		os.Stdout,
	)
	if err := watcher.Watch(ctx); err != nil {
		log.Fatal(err)
	}
}
